==> user_bulk_delete-1.0.0.tar.gz: user_bulk_delete/src/Form/UserBulkDeleteConfirmForm.php <==
<?php

namespace Drupal\user_bulk_delete\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class initialisation.
 */
class UserBulkDeleteConfirmForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'user_bulk_delete_confirm_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $results = NULL) {
    // Store the user IDs in the form state.
    $user_ids = [];
    foreach ($results as $result) {
      $user_ids[$result->uid] = $result->name;
    }

    $form['user_ids'] = [
      '#type' => 'value',
      '#value' => $user_ids,
    ];

    // Display the list of users to be deleted.
    $form['users'] = [
      '#type' => 'item',
      '#markup' => $this->formatPlural(count($user_ids), 'User: @names', 'Users: @names', ['@names' => implode(', ', $user_ids)]),
    ];

    $form['confirm'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('I confirm that I want to delete the above users.'),
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Delete selected users'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $user_ids = array_keys($form_state->getValue('user_ids'));

    if (!empty($user_ids)) {
      $database = \Drupal::database();
      $database->delete('users_field_data')
        ->condition('uid', $user_ids, 'IN')
        ->execute();

      $this->messenger()->addMessage($this->t('Deleted @count users.', ['@count' => count($user_ids)]));
    }
  }

}

==> user_bulk_delete-1.0.1.tar.gz: user_bulk_delete/src/Form/UserBulkDeleteConfirmForm.php <==
<?php

namespace Drupal\user_bulk_delete\Form;

use Drupal\Core\Database\Connection;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class initialisation.
 */
class UserBulkDeleteConfirmForm extends FormBase {

  /**
   * Database connection.
   */
  protected Connection $database;

  /**
   * Constructs a UserBulkDeleteConfirmForm object.
   *
   * @param \Drupal\Core\Database\Connection $database
   *   Database connection.
   */
  public function __construct(Connection $database) {
    $this->database = $database;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'user_bulk_delete_confirm_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $results = NULL) {
    // Store the user IDs in the form state.
    $user_ids = [];
    foreach ($results as $result) {
      $user_ids[$result->uid] = $result->name;
    }

    $form['user_ids'] = [
      '#type' => 'value',
      '#value' => $user_ids,
    ];

    // Display the list of users to be deleted.
    $form['users'] = [
      '#type' => 'item',
      '#markup' => $this->formatPlural(count($user_ids), 'User: @names', 'Users: @names', ['@names' => implode(', ', $user_ids)]),
    ];

    $form['confirm'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('I confirm that I want to delete the above users.'),
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Delete selected users'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $user_ids = array_keys($form_state->getValue('user_ids'));

    if (!empty($user_ids)) {
      $this->database->delete('users_field_data')
        ->condition('uid', $user_ids, 'IN')
        ->execute();

      $this->messenger()->addMessage($this->t('Deleted @count users.', ['@count' => count($user_ids)]));
    }
  }

}
